@@ -89,7 +89,7 @@ $using_guest_account = false;
 <div id='breadCrumbBar' class='breadCrumbBar'>
 	<div id='navBar' class='navBar'><?php echo draw_navigation_text();?></div>
 	<div class='scrollBar'></div>
-	<div class='infoBar'><?php echo draw_login_status($using_guest_account);?></div>
+	<?php if (read_config_option('auth_method') != 0) {?><div class='infoBar'><?php echo draw_login_status($using_guest_account);?></div><?php }?>
 </div>
 <div id='cactiContent' class='cactiContent'>
 	<div class='cactiConsoleNavigationArea' style='overflow:hidden'>
