@@ -32,7 +32,8 @@
    @param $retries - the number a time the server should attempt to connect before failing
    @returns - (bool) '1' for success, '0' for error */
 function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $port = '3306', $db_ssl = false, $retries = 20) {
-	global $database_sessions;
+	global $database_sessions, $database_total_queries;
+	$database_total_queries = 0;
 
 	$i = 0;
 	$error = '';
@@ -117,7 +118,8 @@ function db_execute($sql, $log = TRUE, $db_conn = FALSE) {
    @param $log - whether to log error messages, defaults to true
    @returns - '1' for success, '0' for error */
 function db_execute_prepared($sql, $parms = array(), $log = TRUE, $db_conn = FALSE) {
-	global $database_sessions, $database_default, $config, $database_hostname, $database_port;
+	global $database_sessions, $database_default, $config, $database_hostname, $database_port, $database_total_queries;
+	$database_total_queries++;
 
 	/* check for a connection being passed, if not use legacy behavior */
 	if (!is_object($db_conn)) {
@@ -206,7 +208,8 @@ function db_fetch_cell($sql, $col_name = '', $log = TRUE, $db_conn = FALSE) {
    @param $log - whether to log error messages, defaults to true
    @returns - (bool) the output of the sql query as a single variable */
 function db_fetch_cell_prepared($sql, $parms = array(), $col_name = '', $log = TRUE, $db_conn = FALSE) {
-	global $database_sessions, $database_default, $config, $database_hostname, $database_port;
+	global $database_sessions, $database_default, $config, $database_hostname, $database_port, $database_total_queries;
+	$database_total_queries++;
 
 	/* check for a connection being passed, if not use legacy behavior */
 	if (!is_object($db_conn)) {
@@ -261,7 +264,8 @@ function db_fetch_row($sql, $log = TRUE, $db_conn = FALSE) {
    @param $log - whether to log error messages, defaults to true
    @returns - the first row of the result as a hash */
 function db_fetch_row_prepared($sql, $parms = array(), $log = TRUE, $db_conn = FALSE) {
-	global $database_sessions, $database_default, $config, $database_hostname, $database_port;
+	global $database_sessions, $database_default, $config, $database_hostname, $database_port, $database_total_queries;
+	$database_total_queries++;
 
 	/* check for a connection being passed, if not use legacy behavior */
 	if (!is_object($db_conn)) {
@@ -321,7 +325,8 @@ function db_fetch_assoc($sql, $log = TRUE, $db_conn = FALSE) {
    @param $log - whether to log error messages, defaults to true
    @returns - the entire result set as a multi-dimensional hash */
 function db_fetch_assoc_prepared($sql, $parms = array(), $log = TRUE, $db_conn = FALSE) {
-	global $database_sessions, $database_default, $config, $database_hostname, $database_port;
+	global $database_sessions, $database_default, $config, $database_hostname, $database_port, $database_total_queries;
+	$database_total_queries++;
 
 	/* check for a connection being passed, if not use legacy behavior */
 	if (!is_object($db_conn)) {
@@ -481,6 +486,27 @@ function db_remove_column ($table, $column, $log = TRUE, $db_conn = FALSE) {
 	return true;
 }
 
+/* db_add_index - adds a new index to a table
+   @param $table - the name of the table
+   @param $type - the type of the index
+   @param $key - the name of the index
+   @param $columns - an array that defines the columns to include in the index
+   @returns - (bool) the result of the operation true or false */
+function db_add_index($table, $type, $key, $columns) {
+	if (!is_array($columns)) {
+		$columns = array($columns);
+	}
+	
+	$sql = 'ALTER TABLE `' . $table . '` ADD ' . $type . ' `' . $key . '`(`' . implode('`,`', $columns) . '`)';
+
+	if (db_index_exists($table, $key, false)) {
+		$type = str_ireplace('UNIQUE ', '', $type);
+		db_execute("ALTER TABLE $table DROP $type $key");
+	}
+
+	return db_execute($sql);
+}
+
 /* db_index_exists - checks whether an index exists
    @param $table - the name of the table
    @param $index - the name of the index
